@@ -33,6 +33,17 @@ pub enum NodeElderChange {
     None,
 }
 
+/// Bound name of elders and section_key, section_prefix info together.
+#[derive(Debug, Clone, PartialEq)]
+pub struct Elders {
+    /// The prefix of the section.
+    pub prefix: Prefix,
+    /// The BLS public key of a section.
+    pub key: bls::PublicKey,
+    /// The set of elders of a section.
+    pub elders: BTreeSet<XorName>,
+}
+
 /// An Event raised by a `Node` or `Client` via its event sender.
 ///
 /// These are sent by sn_routing to the library's user. It allows the user to handle requests and
@@ -73,15 +84,11 @@ pub enum Event {
     },
     /// The set of elders in our section has changed.
     EldersChanged {
-        /// The prefix of our section.
-        prefix: Prefix,
-        /// The BLS public key of our section.
-        key: bls::PublicKey,
-        /// The BLS public key of the sibling section, if this event is fired during a split.
+        /// The Elders of our section.
+        elders: Elders,
+        /// The Elders of the sibling section, if this event is fired during a split.
         /// Otherwise `None`.
-        sibling_key: Option<bls::PublicKey>,
-        /// The set of elders of our section.
-        elders: BTreeSet<XorName>,
+        sibling_elders: Option<Elders>,
         /// Promoted, demoted or no change?
         self_status_change: NodeElderChange,
     },
@@ -142,17 +149,13 @@ impl Debug for Event {
                 .field("age", age)
                 .finish(),
             Self::EldersChanged {
-                prefix,
-                key,
-                sibling_key,
                 elders,
+                sibling_elders,
                 self_status_change,
             } => formatter
                 .debug_struct("EldersChanged")
-                .field("prefix", prefix)
-                .field("key", key)
-                .field("sibling_key", sibling_key)
                 .field("elders", elders)
+                .field("sibling_elders", sibling_elders)
                 .field("self_status_change", self_status_change)
                 .finish(),
             Self::RelocationStarted { previous_name } => formatter
