@@ -515,8 +515,9 @@ mod tests {
         let pk1_sig = sk0.sign(&bincode::serialize(&pk1)?);
         let _ = full_proof_chain.insert(&pk0, pk1, pk1_sig);
 
-        let (elders_info, _) = section::test_utils::gen_elders_info(Prefix::default(), 3);
-        let elders_info = agreement::test_utils::proven(&sk1, elders_info)?;
+        let (section_auth, _) =
+            section::test_utils::gen_section_authority_provider(Prefix::default(), 3);
+        let section_auth = agreement::test_utils::proven(&sk1, section_auth)?;
 
         let peer = Peer::new(rand::random(), gen_addr());
         let member_info = MemberInfo::joined(peer);
@@ -524,7 +525,7 @@ mod tests {
 
         let variant = Variant::NodeApproval {
             genesis_key: pk0,
-            elders_info,
+            section_auth,
             member_info,
         };
         let message = Message::single_src(
