@@ -30,11 +30,11 @@ use self::{
 use crate::{
     crypto,
     error::Result,
-    event::{Event, NodeElderChange},
+    event::{Elders, Event, NodeElderChange},
     messages::Message,
     node::Node,
     peer::Peer,
-    section::{EldersInfo, SectionChain},
+    section::{SectionAuthorityProvider, SectionChain},
     Error, TransportConfig, MIN_ADULT_AGE,
 };
 use bytes::Bytes;
@@ -114,11 +114,20 @@ impl Routing {
 
             let section = state.section();
 
-            state.send_event(Event::EldersChanged {
+            let elders = Elders {
                 prefix: *section.prefix(),
                 key: *section.chain().last_key(),
-                sibling_key: None,
-                elders: section.elders_info().elders.keys().copied().collect(),
+                elders: section
+                    .authority_provider()
+                    .elders
+                    .keys()
+                    .copied()
+                    .collect(),
+            };
+
+            state.send_event(Event::EldersChanged {
+                elders,
+                sibling_elders: None,
                 self_status_change: NodeElderChange::Promoted,
             });
 
@@ -259,9 +268,8 @@ impl Routing {
             .lock()
             .await
             .section()
-            .elders_info()
+            .authority_provider()
             .peers()
-            .copied()
             .collect()
     }
 
@@ -297,18 +305,18 @@ impl Routing {
     }
 
     /// Returns the info about our section or `None` if we are not joined yet.
-    pub async fn our_section(&self) -> EldersInfo {
+    pub async fn our_section(&self) -> SectionAuthorityProvider {
         self.dispatcher
             .core
             .lock()
             .await
             .section()
-            .elders_info()
+            .authority_provider()
             .clone()
     }
 
     /// Returns the info about other sections in the network known to us.
-    pub async fn other_sections(&self) -> Vec<EldersInfo> {
+    pub async fn other_sections(&self) -> Vec<SectionAuthorityProvider> {
         self.dispatcher
             .core
             .lock()
@@ -333,10 +341,10 @@ impl Routing {
     pub async fn matching_section(
         &self,
         name: &XorName,
-    ) -> (Option<bls::PublicKey>, Option<EldersInfo>) {
+    ) -> (Option<bls::PublicKey>, Option<SectionAuthorityProvider>) {
         let state = self.dispatcher.core.lock().await;
-        let (key, elders_info) = state.matching_section(name);
-        (key.copied(), elders_info.cloned())
+        let (key, section_auth) = state.matching_section(name);
+        (key.copied(), section_auth.cloned())
     }
 
     /// Send a message.
